@@ -5,6 +5,7 @@ Created on 2022-08-14
 '''
 import datetime
 import os
+import sys
 from dataclasses import dataclass
 from typing import Dict, List, Union
 from urllib.error import HTTPError
@@ -13,7 +14,7 @@ from spreadsheet.wikidata import PropertyMapping, UrlReference, WdDatatype, Wiki
 
 from ceurws.utils.download import Download
 from lodstorage.lod import LOD
-from ceurws.ceur_ws import Volume, VolumeManager, CEURWS
+from ceurws.ceur_ws import Volume, VolumeManager, CEURWS, PaperManager
 from lodstorage.sparql import SPARQL
 from lodstorage.sql import SQLDB
 from lodstorage.query import QueryManager, EndpointManager
@@ -34,6 +35,7 @@ class WikidataSync(object):
         '''
         self.debug = debug
         self.prepareVolumeManager()
+        self.preparePaperManager()
         self.prepareRDF()
         self.wdQuery = self.qm.queriesByName["Proceedings"]
         self.baseurl=baseurl
@@ -62,6 +64,16 @@ class WikidataSync(object):
         qYamlFile = f"{path}/resources/queries/ceurws.yaml"
         if os.path.isfile(qYamlFile):
             self.qm = QueryManager(lang="sparql", queriesPath=qYamlFile)
+            
+    def preparePaperManager(self):
+        """
+        prepare my paper Manager
+        """
+        self.pm=PaperManager()
+        if self.pm.isCached():
+            self.pm.fromStore(cacheFile=CEURWS.CACHE_FILE)
+        else:
+            print("PaperManager not cached you might want to run ceur-ws --recreate",file=sys.stderr)
 
     def prepareVolumeManager(self):
         '''
@@ -109,6 +121,9 @@ class WikidataSync(object):
         return refreshVolumesByNumber,newVolumes
 
     def storeVolumes(self):
+        """
+        store my volumes
+        """
         self.vm.store()
 
     def getWikidataProceedingsRecord(self, volume):
@@ -768,15 +783,15 @@ class WikidataSync(object):
                     id_query = DblpAuthorIdentifier.getWikidataIdQueryPart(id_name, id_value, "?person")
                 else:
                     if id_name == "homepage":
-                        id_query = f"{{OPTIONAL{{ ?person wdt:P856 <{id_value}>.}} }}"
+                        id_query = f"{{ ?person wdt:P856 <{id_value}>. }}"
                 if id_query is not None:
                     optional_clauses.append(id_query)
         id_queries = "\nUNION\n".join(optional_clauses)
-        query = f"""SELECT ?person ?personLabel
-                    WHERE 
+        query = f"""SELECT DISTINCT ?person ?personLabel
+                    WHERE
                     {{
                         {id_queries}
-                        SERVICE wikibase:label {{bd:serviceParam wikibase:language "[AUTO_LANGUAGE],en". }}
+                        ?person rdfs:label ?personLabel. FILTER(lang(?personLabel)="en").
                     }}"""
         qres = self.sparql.queryAsListOfDicts(query)
         res = dict()
@@ -902,14 +917,14 @@ class DblpEndpoint:
                 {id_var}_blank datacite:usesIdentifierScheme {identifier.dblp_property};
                 litre:hasLiteralValue {id_var}Var.}}""")
             id_vars.append(id_var)
-        id_selects = "\n".join([f"(group_concat({id_var}Var;separator='|') as {id_var})" for id_var in id_vars])
+        id_selects = "\n".join([f"(group_concat(DISTINCT {id_var}Var;separator='|') as {id_var})" for id_var in id_vars])
         id_queries = "\n".join(optional_clauses)
         query = f"""PREFIX datacite: <http://purl.org/spar/datacite/>
                     PREFIX dblp: <https://dblp.org/rdf/schema#>
                     PREFIX litre: <http://purl.org/spar/literal/>
-                    SELECT DISTINCT (group_concat(?nameVar;separator='|') as ?name) 
-                                    (group_concat(?homepageVar;separator='|') as ?homepage)
-                                    (group_concat(?affiliationVar;separator='|') as ?affiliation)
+                    SELECT DISTINCT (group_concat(DISTINCT ?nameVar;separator='|') as ?name) 
+                                    (group_concat(DISTINCT ?homepageVar;separator='|') as ?homepage)
+                                    (group_concat(DISTINCT ?affiliationVar;separator='|') as ?affiliation)
                                     {id_selects}
                     WHERE{{
                         ?proceeding dblp:publishedIn "CEUR Workshop Proceedings";
@@ -1005,7 +1020,7 @@ class DblpAuthorIdentifier:
                             {var} wdt:{wd_prop} ?{id_name}.}} 
                             }}  # {id_name}"""
             else:
-                query = f"""{{OPTIONAL{{ {var} wdt:{wd_prop} "{value}".}} }}  # {id_name}"""
+                query = f"""{{ {var} wdt:{wd_prop} "{value}". }}  # {id_name}"""
         else:
             pass
         return query
