@@ -300,7 +300,7 @@ class TestWikidataSync(Basetest):
         self.wdSync.login()
         for wdUrl, volumeNumber in volumesWithMissingAcronym:
             qId = wdUrl[len("http://www.wikidata.org/entity/"):]
-            scrapedDict = volumeParser.parse_volume(volumeNumber)
+            scrapedDict,_soup = volumeParser.parse_volume(volumeNumber)
             acronym = scrapedDict.get("acronym")
             if acronym is not None and len(acronym) < 20:
                 print(f"{qId}:✅ Adding Acronym {acronym}")
@@ -342,11 +342,11 @@ class TestWikidataSync(Basetest):
             (dict(), set()),
             ({"orcid": "0000-0003-3587-0367", "dblp": "00/11426"}, {"Q58990389"}),
             ({"googleScholar": "xgXBIvQAAAAJ", "dblp": "00/11426"}, {"Q58990389", "Q20559326"}),
-            ({"googleScholar": "xgXBIvQAAAAJ", "dblp": "00/11426", "acm": "81100237147"}, {"Q58990389", "Q20559326"}),  # test empty query row error
-            ({"homepage": "http://www.stefandecker.org"}, {"Q54303353"})
+            ({"googleScholar": "xgXBIvQAAAAJ", "dblp": "00/11426", "acm": "81100237147"}, {"Q58990389", "Q20559326", "Q61248440"}),  # test empty query row error
+            ({"homepage": "http://www.stefandecker.org", "gnd": "173443443", "dblp":"d/StefanDecker"}, {"Q54303353"})
         ]
         for param in test_params:
-            with self.subTest("Test finding authors by ssets of ids", param=param):
+            with self.subTest("Test finding authors by sets of ids", param=param):
                 identifiers, expected_items = param
                 found_authors = self.wdSync.getAuthorByIds(identifiers)
                 ids = set(found_authors.keys())
@@ -361,7 +361,7 @@ class TestWikidataSync(Basetest):
         res = []
         editors = self.wdSync.dbpEndpoint.getEditorsOfVolume(None)
         total = len(editors)
-        for i, identifiers in enumerate(editors[:5]):
+        for i, identifiers in enumerate(editors):
             editor = identifiers.get("name")
             print(f"({i+1:04}/{total})", end=" ")
             authors = self.wdSync.getAuthorByIds(identifiers)
@@ -427,7 +427,7 @@ class TestWikidataSync(Basetest):
         limit = 3200
         homepages = []
         for volnumber in range(start, limit):
-            scrapedDict = parser.parse_volume(volnumber, use_cache=True)
+            scrapedDict,_soup = parser.parse_volume(volnumber, use_cache=True)
             homepage = scrapedDict.get("homepage", None)
             if homepage is not None and homepage.startswith("http"):
                 homepages.append((volnumber, scrapedDict["homepage"].strip()))
